@@ -1,4 +1,4 @@
-.onLoad <-function (lib, pkg) {
+.onAttach <-function (lib, pkg) {
   packageStartupMessage("     Loading library saemix, version 0.96, July 1st, 2011\n         please direct bugs, questions and feedback to emmanuelle.comets@inserm.fr\n")
 #  cat("     Loading library saemix, version 0.95, June 15th, 2011\n")
 #  cat("         please direct bugs, questions and feedback to emmanuelle.comets@inserm.fr\n")
